# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpdateUserRequestBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'username': 'str',
        'nickname': 'str',
        'home_resource': 'str',
        'email': 'str',
        'password': 'str',
        'role': 'str',
        'permissions': 'UsersPermissions',
        'time_zone': 'str',
        'expiration': 'str',
        'locked': 'bool',
        'onboarding': 'bool',
        'current_user_password': 'str'
    }

    attribute_map = {
        'username': 'username',
        'nickname': 'nickname',
        'home_resource': 'homeResource',
        'email': 'email',
        'password': 'password',
        'role': 'role',
        'permissions': 'permissions',
        'time_zone': 'timeZone',
        'expiration': 'expiration',
        'locked': 'locked',
        'onboarding': 'onboarding',
        'current_user_password': 'currentUserPassword'
    }

    def __init__(self, username=None, nickname=None, home_resource=None, email=None, password=None, role=None, permissions=None, time_zone=None, expiration=None, locked=None, onboarding=None, current_user_password=None):  # noqa: E501
        """UpdateUserRequestBody - a model defined in Swagger"""  # noqa: E501
        self._username = None
        self._nickname = None
        self._home_resource = None
        self._email = None
        self._password = None
        self._role = None
        self._permissions = None
        self._time_zone = None
        self._expiration = None
        self._locked = None
        self._onboarding = None
        self._current_user_password = None
        self.discriminator = None
        if username is not None:
            self.username = username
        if nickname is not None:
            self.nickname = nickname
        if home_resource is not None:
            self.home_resource = home_resource
        if email is not None:
            self.email = email
        if password is not None:
            self.password = password
        if role is not None:
            self.role = role
        if permissions is not None:
            self.permissions = permissions
        if time_zone is not None:
            self.time_zone = time_zone
        if expiration is not None:
            self.expiration = expiration
        if locked is not None:
            self.locked = locked
        if onboarding is not None:
            self.onboarding = onboarding
        if current_user_password is not None:
            self.current_user_password = current_user_password

    @property
    def username(self):
        """Gets the username of this UpdateUserRequestBody.  # noqa: E501

        New username for the user. This should follow standard username conventions - spaces are not allowed, etc. We do allow email addresses as usernames.  **Note** Usernames must be unique across all ExaVault accounts.  # noqa: E501

        :return: The username of this UpdateUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this UpdateUserRequestBody.

        New username for the user. This should follow standard username conventions - spaces are not allowed, etc. We do allow email addresses as usernames.  **Note** Usernames must be unique across all ExaVault accounts.  # noqa: E501

        :param username: The username of this UpdateUserRequestBody.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def nickname(self):
        """Gets the nickname of this UpdateUserRequestBody.  # noqa: E501

        An optional nickname (e.g. 'David from Sales').  # noqa: E501

        :return: The nickname of this UpdateUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._nickname

    @nickname.setter
    def nickname(self, nickname):
        """Sets the nickname of this UpdateUserRequestBody.

        An optional nickname (e.g. 'David from Sales').  # noqa: E501

        :param nickname: The nickname of this UpdateUserRequestBody.  # noqa: E501
        :type: str
        """

        self._nickname = nickname

    @property
    def home_resource(self):
        """Gets the home_resource of this UpdateUserRequestBody.  # noqa: E501

        Resource identifier for the user's home folder. See details on [how to specify resources](#section/Identifying-Resources) above.  The user will be locked to this directory and unable to move 'up' in the account. If the folder does not exist in the account, it will be created when the user logs in.  This setting is ignored for users with the `role` **admin**.  # noqa: E501

        :return: The home_resource of this UpdateUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._home_resource

    @home_resource.setter
    def home_resource(self, home_resource):
        """Sets the home_resource of this UpdateUserRequestBody.

        Resource identifier for the user's home folder. See details on [how to specify resources](#section/Identifying-Resources) above.  The user will be locked to this directory and unable to move 'up' in the account. If the folder does not exist in the account, it will be created when the user logs in.  This setting is ignored for users with the `role` **admin**.  # noqa: E501

        :param home_resource: The home_resource of this UpdateUserRequestBody.  # noqa: E501
        :type: str
        """

        self._home_resource = home_resource

    @property
    def email(self):
        """Gets the email of this UpdateUserRequestBody.  # noqa: E501

        Email address for the user  # noqa: E501

        :return: The email of this UpdateUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UpdateUserRequestBody.

        Email address for the user  # noqa: E501

        :param email: The email of this UpdateUserRequestBody.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def password(self):
        """Gets the password of this UpdateUserRequestBody.  # noqa: E501

        New password for the user  # noqa: E501

        :return: The password of this UpdateUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this UpdateUserRequestBody.

        New password for the user  # noqa: E501

        :param password: The password of this UpdateUserRequestBody.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def role(self):
        """Gets the role of this UpdateUserRequestBody.  # noqa: E501

        The type of user (**admin** or **user**). Note that admin users cannot have a `homeResource` other than '/', and will have full permissions, but you must provide at least \"download,upload,list,delete\" in the `permissions` parameter.  # noqa: E501

        :return: The role of this UpdateUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this UpdateUserRequestBody.

        The type of user (**admin** or **user**). Note that admin users cannot have a `homeResource` other than '/', and will have full permissions, but you must provide at least \"download,upload,list,delete\" in the `permissions` parameter.  # noqa: E501

        :param role: The role of this UpdateUserRequestBody.  # noqa: E501
        :type: str
        """
        allowed_values = ["user", "admin"]  # noqa: E501
        if role not in allowed_values:
            raise ValueError(
                "Invalid value for `role` ({0}), must be one of {1}"  # noqa: E501
                .format(role, allowed_values)
            )

        self._role = role

    @property
    def permissions(self):
        """Gets the permissions of this UpdateUserRequestBody.  # noqa: E501


        :return: The permissions of this UpdateUserRequestBody.  # noqa: E501
        :rtype: UsersPermissions
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this UpdateUserRequestBody.


        :param permissions: The permissions of this UpdateUserRequestBody.  # noqa: E501
        :type: UsersPermissions
        """

        self._permissions = permissions

    @property
    def time_zone(self):
        """Gets the time_zone of this UpdateUserRequestBody.  # noqa: E501

        Time zone, used for accurate time display within the application. See <a href='https://php.net/manual/en/timezones.php' target='blank'>this page</a> for allowed values.   # noqa: E501

        :return: The time_zone of this UpdateUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this UpdateUserRequestBody.

        Time zone, used for accurate time display within the application. See <a href='https://php.net/manual/en/timezones.php' target='blank'>this page</a> for allowed values.   # noqa: E501

        :param time_zone: The time_zone of this UpdateUserRequestBody.  # noqa: E501
        :type: str
        """

        self._time_zone = time_zone

    @property
    def expiration(self):
        """Gets the expiration of this UpdateUserRequestBody.  # noqa: E501

        Optional timestamp when the user should expire.  # noqa: E501

        :return: The expiration of this UpdateUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """Sets the expiration of this UpdateUserRequestBody.

        Optional timestamp when the user should expire.  # noqa: E501

        :param expiration: The expiration of this UpdateUserRequestBody.  # noqa: E501
        :type: str
        """

        self._expiration = expiration

    @property
    def locked(self):
        """Gets the locked of this UpdateUserRequestBody.  # noqa: E501

        If true, the user will be prevented from logging in  # noqa: E501

        :return: The locked of this UpdateUserRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this UpdateUserRequestBody.

        If true, the user will be prevented from logging in  # noqa: E501

        :param locked: The locked of this UpdateUserRequestBody.  # noqa: E501
        :type: bool
        """

        self._locked = locked

    @property
    def onboarding(self):
        """Gets the onboarding of this UpdateUserRequestBody.  # noqa: E501

        Set this to **true** to enable extra help popups in the web file manager for this user.  # noqa: E501

        :return: The onboarding of this UpdateUserRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._onboarding

    @onboarding.setter
    def onboarding(self, onboarding):
        """Sets the onboarding of this UpdateUserRequestBody.

        Set this to **true** to enable extra help popups in the web file manager for this user.  # noqa: E501

        :param onboarding: The onboarding of this UpdateUserRequestBody.  # noqa: E501
        :type: bool
        """

        self._onboarding = onboarding

    @property
    def current_user_password(self):
        """Gets the current_user_password of this UpdateUserRequestBody.  # noqa: E501

        The password of the currently authenticated user. Required when updating any user’s email, username or password.  # noqa: E501

        :return: The current_user_password of this UpdateUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._current_user_password

    @current_user_password.setter
    def current_user_password(self, current_user_password):
        """Sets the current_user_password of this UpdateUserRequestBody.

        The password of the currently authenticated user. Required when updating any user’s email, username or password.  # noqa: E501

        :param current_user_password: The current_user_password of this UpdateUserRequestBody.  # noqa: E501
        :type: str
        """

        self._current_user_password = current_user_password

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateUserRequestBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateUserRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WebhooksActivityEntryAttributes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attempt': 'int',
        'created': 'str',
        'endpoint_url': 'str',
        'event': 'str',
        'response': 'str',
        'response_size': 'int',
        'status': 'int'
    }

    attribute_map = {
        'attempt': 'attempt',
        'created': 'created',
        'endpoint_url': 'endpointUrl',
        'event': 'event',
        'response': 'response',
        'response_size': 'responseSize',
        'status': 'status'
    }

    def __init__(self, attempt=None, created=None, endpoint_url=None, event=None, response=None, response_size=None, status=None):  # noqa: E501
        """WebhooksActivityEntryAttributes - a model defined in Swagger"""  # noqa: E501
        self._attempt = None
        self._created = None
        self._endpoint_url = None
        self._event = None
        self._response = None
        self._response_size = None
        self._status = None
        self.discriminator = None
        if attempt is not None:
            self.attempt = attempt
        if created is not None:
            self.created = created
        if endpoint_url is not None:
            self.endpoint_url = endpoint_url
        if event is not None:
            self.event = event
        if response is not None:
            self.response = response
        if response_size is not None:
            self.response_size = response_size
        if status is not None:
            self.status = status

    @property
    def attempt(self):
        """Gets the attempt of this WebhooksActivityEntryAttributes.  # noqa: E501


        :return: The attempt of this WebhooksActivityEntryAttributes.  # noqa: E501
        :rtype: int
        """
        return self._attempt

    @attempt.setter
    def attempt(self, attempt):
        """Sets the attempt of this WebhooksActivityEntryAttributes.


        :param attempt: The attempt of this WebhooksActivityEntryAttributes.  # noqa: E501
        :type: int
        """

        self._attempt = attempt

    @property
    def created(self):
        """Gets the created of this WebhooksActivityEntryAttributes.  # noqa: E501


        :return: The created of this WebhooksActivityEntryAttributes.  # noqa: E501
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this WebhooksActivityEntryAttributes.


        :param created: The created of this WebhooksActivityEntryAttributes.  # noqa: E501
        :type: str
        """

        self._created = created

    @property
    def endpoint_url(self):
        """Gets the endpoint_url of this WebhooksActivityEntryAttributes.  # noqa: E501


        :return: The endpoint_url of this WebhooksActivityEntryAttributes.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_url

    @endpoint_url.setter
    def endpoint_url(self, endpoint_url):
        """Sets the endpoint_url of this WebhooksActivityEntryAttributes.


        :param endpoint_url: The endpoint_url of this WebhooksActivityEntryAttributes.  # noqa: E501
        :type: str
        """

        self._endpoint_url = endpoint_url

    @property
    def event(self):
        """Gets the event of this WebhooksActivityEntryAttributes.  # noqa: E501


        :return: The event of this WebhooksActivityEntryAttributes.  # noqa: E501
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this WebhooksActivityEntryAttributes.


        :param event: The event of this WebhooksActivityEntryAttributes.  # noqa: E501
        :type: str
        """

        self._event = event

    @property
    def response(self):
        """Gets the response of this WebhooksActivityEntryAttributes.  # noqa: E501


        :return: The response of this WebhooksActivityEntryAttributes.  # noqa: E501
        :rtype: str
        """
        return self._response

    @response.setter
    def response(self, response):
        """Sets the response of this WebhooksActivityEntryAttributes.


        :param response: The response of this WebhooksActivityEntryAttributes.  # noqa: E501
        :type: str
        """

        self._response = response

    @property
    def response_size(self):
        """Gets the response_size of this WebhooksActivityEntryAttributes.  # noqa: E501


        :return: The response_size of this WebhooksActivityEntryAttributes.  # noqa: E501
        :rtype: int
        """
        return self._response_size

    @response_size.setter
    def response_size(self, response_size):
        """Sets the response_size of this WebhooksActivityEntryAttributes.


        :param response_size: The response_size of this WebhooksActivityEntryAttributes.  # noqa: E501
        :type: int
        """

        self._response_size = response_size

    @property
    def status(self):
        """Gets the status of this WebhooksActivityEntryAttributes.  # noqa: E501


        :return: The status of this WebhooksActivityEntryAttributes.  # noqa: E501
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this WebhooksActivityEntryAttributes.


        :param status: The status of this WebhooksActivityEntryAttributes.  # noqa: E501
        :type: int
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhooksActivityEntryAttributes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhooksActivityEntryAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResourceRelationships(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'share': 'ResourceRelationshipsShare',
        'notifications': 'list[ResourceRelationshipsNotifications]',
        'direct_file': 'ResourceRelationshipsDirectFile',
        'parent_resource': 'ResourceRelationshipsParentResource'
    }

    attribute_map = {
        'share': 'share',
        'notifications': 'notifications',
        'direct_file': 'directFile',
        'parent_resource': 'parentResource'
    }

    def __init__(self, share=None, notifications=None, direct_file=None, parent_resource=None):  # noqa: E501
        """ResourceRelationships - a model defined in Swagger"""  # noqa: E501
        self._share = None
        self._notifications = None
        self._direct_file = None
        self._parent_resource = None
        self.discriminator = None
        if share is not None:
            self.share = share
        if notifications is not None:
            self.notifications = notifications
        if direct_file is not None:
            self.direct_file = direct_file
        if parent_resource is not None:
            self.parent_resource = parent_resource

    @property
    def share(self):
        """Gets the share of this ResourceRelationships.  # noqa: E501


        :return: The share of this ResourceRelationships.  # noqa: E501
        :rtype: ResourceRelationshipsShare
        """
        return self._share

    @share.setter
    def share(self, share):
        """Sets the share of this ResourceRelationships.


        :param share: The share of this ResourceRelationships.  # noqa: E501
        :type: ResourceRelationshipsShare
        """

        self._share = share

    @property
    def notifications(self):
        """Gets the notifications of this ResourceRelationships.  # noqa: E501


        :return: The notifications of this ResourceRelationships.  # noqa: E501
        :rtype: list[ResourceRelationshipsNotifications]
        """
        return self._notifications

    @notifications.setter
    def notifications(self, notifications):
        """Sets the notifications of this ResourceRelationships.


        :param notifications: The notifications of this ResourceRelationships.  # noqa: E501
        :type: list[ResourceRelationshipsNotifications]
        """

        self._notifications = notifications

    @property
    def direct_file(self):
        """Gets the direct_file of this ResourceRelationships.  # noqa: E501


        :return: The direct_file of this ResourceRelationships.  # noqa: E501
        :rtype: ResourceRelationshipsDirectFile
        """
        return self._direct_file

    @direct_file.setter
    def direct_file(self, direct_file):
        """Sets the direct_file of this ResourceRelationships.


        :param direct_file: The direct_file of this ResourceRelationships.  # noqa: E501
        :type: ResourceRelationshipsDirectFile
        """

        self._direct_file = direct_file

    @property
    def parent_resource(self):
        """Gets the parent_resource of this ResourceRelationships.  # noqa: E501


        :return: The parent_resource of this ResourceRelationships.  # noqa: E501
        :rtype: ResourceRelationshipsParentResource
        """
        return self._parent_resource

    @parent_resource.setter
    def parent_resource(self, parent_resource):
        """Sets the parent_resource of this ResourceRelationships.


        :param parent_resource: The parent_resource of this ResourceRelationships.  # noqa: E501
        :type: ResourceRelationshipsParentResource
        """

        self._parent_resource = parent_resource

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResourceRelationships, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceRelationships):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from exavault.api_client import ApiClient


class ActivityApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_session_logs(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get activity logs  # noqa: E501

        Returns the detailed activity logs for your account. Optional query paramaters will filter the returned results based on a number of options including usernames, activity types, or date ranges.     **Operation Types** Session activity is logged with an operation type that is different from what is visible through the [activity log interface in the web file manager](/docs/account/10-activity-logs/00-activity-logs). Consult the table below to compare the two:  | File Manager Value | API Value | Notes | |-----|----|---| | Connect | PASS | | | Disconnect | EXIT | | | Upload | STOR | | | Download | RETR | | | Delete | DELE | | | Create Folder | MKD | | | Rename | RNTO | | | Move | MOVE | | | Copy | COPY | | | Compress | COMPR | | | Extract | EXTRACT | | | Shared Folders | SHARE | | | Send Files | SEND | | | Receive Files | RECV | | | _N/A_ | EDIT\\_SEND | Update send. Not shown in file manager | | Update Share | EDIT\\_SHARE| |  | Update Receive | EDIT\\_RECV | | | Delete Send | DELE\\_SEND | | | Delete Receive | DELE\\_RECV | | | Delete Share | DELE\\_SHARE | | | Create Notification | NOTIFY | | | Update Notification | EDIT\\_NTFY| | | Delete Notification | DELE\\_NTFY | | | Create User | USER | | | Update User | EDIT\\_USER | | | Delete User | DELE\\_USER | | | _N/A_ | DFA | Create direct link. Not shown in file manager | | _N/A_ | EDIT\\_DFA | Update direct link options. Not shown in file manager | | _N/A_ | DELE\\_DFA | Deactivate direct link. Not shown in file manager|   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_session_logs(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key (required)
        :param str ev_access_token: Access Token (required)
        :param datetime start_date: Start date of the filter data range
        :param datetime end_date: End date of the filter data range
        :param str ip_address: Used to filter session logs by ip address.
        :param str user_name: Username used for filtering a list
        :param str path: Path used to filter records
        :param str type: Filter session logs for operation type (see table above for acceptable values)
        :param int offset: Offset of the records list
        :param int limit: Limit of the records list
        :param str sort: Comma separated list sort params
        :return: SessionActivityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_session_logs_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_session_logs_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def get_session_logs_with_http_info(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get activity logs  # noqa: E501

        Returns the detailed activity logs for your account. Optional query paramaters will filter the returned results based on a number of options including usernames, activity types, or date ranges.     **Operation Types** Session activity is logged with an operation type that is different from what is visible through the [activity log interface in the web file manager](/docs/account/10-activity-logs/00-activity-logs). Consult the table below to compare the two:  | File Manager Value | API Value | Notes | |-----|----|---| | Connect | PASS | | | Disconnect | EXIT | | | Upload | STOR | | | Download | RETR | | | Delete | DELE | | | Create Folder | MKD | | | Rename | RNTO | | | Move | MOVE | | | Copy | COPY | | | Compress | COMPR | | | Extract | EXTRACT | | | Shared Folders | SHARE | | | Send Files | SEND | | | Receive Files | RECV | | | _N/A_ | EDIT\\_SEND | Update send. Not shown in file manager | | Update Share | EDIT\\_SHARE| |  | Update Receive | EDIT\\_RECV | | | Delete Send | DELE\\_SEND | | | Delete Receive | DELE\\_RECV | | | Delete Share | DELE\\_SHARE | | | Create Notification | NOTIFY | | | Update Notification | EDIT\\_NTFY| | | Delete Notification | DELE\\_NTFY | | | Create User | USER | | | Update User | EDIT\\_USER | | | Delete User | DELE\\_USER | | | _N/A_ | DFA | Create direct link. Not shown in file manager | | _N/A_ | EDIT\\_DFA | Update direct link options. Not shown in file manager | | _N/A_ | DELE\\_DFA | Deactivate direct link. Not shown in file manager|   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_session_logs_with_http_info(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key (required)
        :param str ev_access_token: Access Token (required)
        :param datetime start_date: Start date of the filter data range
        :param datetime end_date: End date of the filter data range
        :param str ip_address: Used to filter session logs by ip address.
        :param str user_name: Username used for filtering a list
        :param str path: Path used to filter records
        :param str type: Filter session logs for operation type (see table above for acceptable values)
        :param int offset: Offset of the records list
        :param int limit: Limit of the records list
        :param str sort: Comma separated list sort params
        :return: SessionActivityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'start_date', 'end_date', 'ip_address', 'user_name', 'path', 'type', 'offset', 'limit', 'sort']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_session_logs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `get_session_logs`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `get_session_logs`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_date' in params:
            query_params.append(('startDate', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('endDate', params['end_date']))  # noqa: E501
        if 'ip_address' in params:
            query_params.append(('ipAddress', params['ip_address']))  # noqa: E501
        if 'user_name' in params:
            query_params.append(('userName', params['user_name']))  # noqa: E501
        if 'path' in params:
            query_params.append(('path', params['path']))  # noqa: E501
        if 'type' in params:
            query_params.append(('type', params['type']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'sort' in params:
            query_params.append(('sort', params['sort']))  # noqa: E501

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/activity/session', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SessionActivityResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_webhook_logs(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get webhook logs  # noqa: E501

        Returns the webhook logs for your account. Optional query paramaters will filter the returned results based on a number of options including path, tpye of event, or status code.   **Event Types**  Webhooks are triggered by enabled event types for your account, which are configured on the [developer settings page](/docs/account/09-settings/06-developer-settings). These are the valid options for event types:  - Upload - Download - Delete File - Delete Folder - Create Folder - Rename - Move - Copy - Compress - Extract - Share Folder - Send Files - Receive Files - Update Share - Update Receive - Delete Send - Delete Receive - Delete Share - Create Notification - Update Notification - Delete Notification - Create User - Update User  - Delete User - Connect - Disconnect  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_webhook_logs(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key (required)
        :param str ev_access_token: Access Token (required)
        :param str event: Filter by triggered event
        :param int status_code: Filter by webhook response status code
        :param str path: Path used to filter records
        :param str username: Filter by triggering username.
        :param int offset: Records to skip before returning results
        :param int limit: Limit of the records list
        :param str sort: Comma separated list sort params
        :return: WebhooksActivityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_webhook_logs_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_webhook_logs_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def get_webhook_logs_with_http_info(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get webhook logs  # noqa: E501

        Returns the webhook logs for your account. Optional query paramaters will filter the returned results based on a number of options including path, tpye of event, or status code.   **Event Types**  Webhooks are triggered by enabled event types for your account, which are configured on the [developer settings page](/docs/account/09-settings/06-developer-settings). These are the valid options for event types:  - Upload - Download - Delete File - Delete Folder - Create Folder - Rename - Move - Copy - Compress - Extract - Share Folder - Send Files - Receive Files - Update Share - Update Receive - Delete Send - Delete Receive - Delete Share - Create Notification - Update Notification - Delete Notification - Create User - Update User  - Delete User - Connect - Disconnect  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_webhook_logs_with_http_info(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key (required)
        :param str ev_access_token: Access Token (required)
        :param str event: Filter by triggered event
        :param int status_code: Filter by webhook response status code
        :param str path: Path used to filter records
        :param str username: Filter by triggering username.
        :param int offset: Records to skip before returning results
        :param int limit: Limit of the records list
        :param str sort: Comma separated list sort params
        :return: WebhooksActivityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'event', 'status_code', 'path', 'username', 'offset', 'limit', 'sort']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_webhook_logs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `get_webhook_logs`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `get_webhook_logs`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'event' in params:
            query_params.append(('event', params['event']))  # noqa: E501
        if 'status_code' in params:
            query_params.append(('statusCode', params['status_code']))  # noqa: E501
        if 'path' in params:
            query_params.append(('path', params['path']))  # noqa: E501
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'sort' in params:
            query_params.append(('sort', params['sort']))  # noqa: E501

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/activity/webhooks', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WebhooksActivityResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FormEntryAttributes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'fields': 'list[FormEntryField]',
        'paths': 'list[str]',
        'status': 'str',
        'created': 'datetime',
        'modified': 'datetime'
    }

    attribute_map = {
        'fields': 'fields',
        'paths': 'paths',
        'status': 'status',
        'created': 'created',
        'modified': 'modified'
    }

    def __init__(self, fields=None, paths=None, status=None, created=None, modified=None):  # noqa: E501
        """FormEntryAttributes - a model defined in Swagger"""  # noqa: E501
        self._fields = None
        self._paths = None
        self._status = None
        self._created = None
        self._modified = None
        self.discriminator = None
        if fields is not None:
            self.fields = fields
        if paths is not None:
            self.paths = paths
        if status is not None:
            self.status = status
        if created is not None:
            self.created = created
        if modified is not None:
            self.modified = modified

    @property
    def fields(self):
        """Gets the fields of this FormEntryAttributes.  # noqa: E501


        :return: The fields of this FormEntryAttributes.  # noqa: E501
        :rtype: list[FormEntryField]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this FormEntryAttributes.


        :param fields: The fields of this FormEntryAttributes.  # noqa: E501
        :type: list[FormEntryField]
        """

        self._fields = fields

    @property
    def paths(self):
        """Gets the paths of this FormEntryAttributes.  # noqa: E501

        Full paths to files associated with the form submission  # noqa: E501

        :return: The paths of this FormEntryAttributes.  # noqa: E501
        :rtype: list[str]
        """
        return self._paths

    @paths.setter
    def paths(self, paths):
        """Sets the paths of this FormEntryAttributes.

        Full paths to files associated with the form submission  # noqa: E501

        :param paths: The paths of this FormEntryAttributes.  # noqa: E501
        :type: list[str]
        """

        self._paths = paths

    @property
    def status(self):
        """Gets the status of this FormEntryAttributes.  # noqa: E501

        Form entry status  # noqa: E501

        :return: The status of this FormEntryAttributes.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this FormEntryAttributes.

        Form entry status  # noqa: E501

        :param status: The status of this FormEntryAttributes.  # noqa: E501
        :type: str
        """
        allowed_values = ["pending", "completed"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def created(self):
        """Gets the created of this FormEntryAttributes.  # noqa: E501

        Timestamp of the submission  # noqa: E501

        :return: The created of this FormEntryAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this FormEntryAttributes.

        Timestamp of the submission  # noqa: E501

        :param created: The created of this FormEntryAttributes.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def modified(self):
        """Gets the modified of this FormEntryAttributes.  # noqa: E501

        Timestamp of the field modified date  # noqa: E501

        :return: The modified of this FormEntryAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this FormEntryAttributes.

        Timestamp of the field modified date  # noqa: E501

        :param modified: The modified of this FormEntryAttributes.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FormEntryAttributes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FormEntryAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from exavault.api.account_api import AccountApi
from exavault.api.activity_api import ActivityApi
from exavault.api.email_api import EmailApi
from exavault.api.email_lists_api import EmailListsApi
from exavault.api.form_api import FormApi
from exavault.api.notifications_api import NotificationsApi
from exavault.api.recipients_api import RecipientsApi
from exavault.api.resources_api import ResourcesApi
from exavault.api.shares_api import SharesApi
from exavault.api.users_api import UsersApi



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages
import sys

if sys.version_info[0] < 3:
    with open('README.md', 'r') as fh:
        long_description = fh.read()
else:
    with open('README.md', 'r', encoding='utf-8') as fh:
        long_description = fh.read()

setup(

    name='exavault',
    version='2.1.4',

    description='Python SDK for interacting with ExaVault API',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/exavault/evapi-python',
    author_email='support@exavault.com',

    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 2.7',
    ],

    keywords='api, exavault, development',

    packages=find_packages(),

    # Specify which Python versions you support. In contrast to the
    # 'Programming Language' classifiers above, 'pip install' will check this
    # and refuse to install the project if the version does not match. See
    # https://packaging.python.org/guides/distributing-packages-using-setuptools/#python-requires
    python_requires='>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, <4',

    install_requires=[
        'certifi',
        'python-dateutil>=2.5.3, <3.0',
        'python-dotenv',
        'setuptools>=21.0.0',
        'six>=1.10',
        'urllib3>=1.15.1'
    ],

    # List additional URLs that are relevant to your project as a dict.
    #
    # This field corresponds to the "Project-URL" metadata fields:
    # https://packaging.python.org/specifications/core-metadata/#project-url-multiple-use
    #
    # Examples listed include a pattern for specifying where the package tracks
    # issues, where the source is hosted, where to say thanks to the package
    # maintainers, and where to support the project financially. The key is
    # what's used to render the link text on PyPI.
    project_urls={  # Optional
        'API Reference': 'https://www.exavault.com/developer/api-docs/',
        'Contact Support': 'https://www.exavault.com/contact/',
        'Source': 'https://github.com/ExaVault/evapi-python/',
    },
)



# coding: utf-8

# flake8: noqa

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from exavault.api.account_api import AccountApi
from exavault.api.activity_api import ActivityApi
from exavault.api.email_api import EmailApi
from exavault.api.email_lists_api import EmailListsApi
from exavault.api.form_api import FormApi
from exavault.api.notifications_api import NotificationsApi
from exavault.api.recipients_api import RecipientsApi
from exavault.api.resources_api import ResourcesApi
from exavault.api.shares_api import SharesApi
from exavault.api.users_api import UsersApi
# import ApiClient
from exavault.api_client import ApiClient
from exavault.configuration import Configuration
# import models into sdk package
from exavault.models.access_mode import AccessMode
from exavault.models.account import Account
from exavault.models.account_allowed_ip_ranges import AccountAllowedIpRanges
from exavault.models.account_attributes import AccountAttributes
from exavault.models.account_attributes_allowed_ip import AccountAttributesAllowedIp
from exavault.models.account_response import AccountResponse
from exavault.models.add_email_list_request_body import AddEmailListRequestBody
from exavault.models.add_folder_request_body import AddFolderRequestBody
from exavault.models.add_notification_request_body import AddNotificationRequestBody
from exavault.models.add_share_request_body import AddShareRequestBody
from exavault.models.add_user_request_body import AddUserRequestBody
from exavault.models.any_of_notification_collection_response_included_items import AnyOfNotificationCollectionResponseIncludedItems
from exavault.models.any_of_notification_response_included_items import AnyOfNotificationResponseIncludedItems
from exavault.models.any_of_resource_collection_response_included_items import AnyOfResourceCollectionResponseIncludedItems
from exavault.models.any_of_resource_multi_response_responses_items import AnyOfResourceMultiResponseResponsesItems
from exavault.models.any_of_resource_response_included_items import AnyOfResourceResponseIncludedItems
from exavault.models.any_of_share_collection_response_included_items import AnyOfShareCollectionResponseIncludedItems
from exavault.models.any_of_share_response_included_items import AnyOfShareResponseIncludedItems
from exavault.models.any_of_user_collection_response_included_items import AnyOfUserCollectionResponseIncludedItems
from exavault.models.any_of_user_response_included_items import AnyOfUserResponseIncludedItems
from exavault.models.branding_settings import BrandingSettings
from exavault.models.branding_settings_values import BrandingSettingsValues
from exavault.models.callback_settings import CallbackSettings
from exavault.models.callback_settings_triggers import CallbackSettingsTriggers
from exavault.models.callback_settings_values import CallbackSettingsValues
from exavault.models.callback_settings_values_triggers import CallbackSettingsValuesTriggers
from exavault.models.compress_files_request_body import CompressFilesRequestBody
from exavault.models.copy_resources_request_body import CopyResourcesRequestBody
from exavault.models.delete_resources_request_body import DeleteResourcesRequestBody
from exavault.models.email_list import EmailList
from exavault.models.email_list_attributes import EmailListAttributes
from exavault.models.email_list_collection_response import EmailListCollectionResponse
from exavault.models.email_list_owner_user import EmailListOwnerUser
from exavault.models.email_list_relationships import EmailListRelationships
from exavault.models.email_list_response import EmailListResponse
from exavault.models.empty_response import EmptyResponse
from exavault.models.error import Error
from exavault.models.extract_files_request_body import ExtractFilesRequestBody
from exavault.models.form import Form
from exavault.models.form_attributes import FormAttributes
from exavault.models.form_entry import FormEntry
from exavault.models.form_entry_attributes import FormEntryAttributes
from exavault.models.form_entry_field import FormEntryField
from exavault.models.form_entry_response import FormEntryResponse
from exavault.models.form_field import FormField
from exavault.models.form_field_settings import FormFieldSettings
from exavault.models.form_field_upload_area import FormFieldUploadArea
from exavault.models.form_field_upload_area_settings import FormFieldUploadAreaSettings
from exavault.models.form_relationships import FormRelationships
from exavault.models.form_relationships_share import FormRelationshipsShare
from exavault.models.form_relationships_share_data import FormRelationshipsShareData
from exavault.models.form_response import FormResponse
from exavault.models.formsid_elements import FormsidElements
from exavault.models.formsid_settings import FormsidSettings
from exavault.models.master_user import MasterUser
from exavault.models.master_user_master_user import MasterUserMasterUser
from exavault.models.master_user_master_user_data import MasterUserMasterUserData
from exavault.models.move_resources_request_body import MoveResourcesRequestBody
from exavault.models.notification import Notification
from exavault.models.notification_attributes import NotificationAttributes
from exavault.models.notification_collection_response import NotificationCollectionResponse
from exavault.models.notification_recipient import NotificationRecipient
from exavault.models.notification_relationships import NotificationRelationships
from exavault.models.notification_relationships_owner_user import NotificationRelationshipsOwnerUser
from exavault.models.notification_relationships_owner_user_data import NotificationRelationshipsOwnerUserData
from exavault.models.notification_relationships_resource import NotificationRelationshipsResource
from exavault.models.notification_relationships_resource_data import NotificationRelationshipsResourceData
from exavault.models.notification_relationships_share import NotificationRelationshipsShare
from exavault.models.notification_relationships_share_data import NotificationRelationshipsShareData
from exavault.models.notification_response import NotificationResponse
from exavault.models.preview_file import PreviewFile
from exavault.models.preview_file_attributes import PreviewFileAttributes
from exavault.models.preview_file_response import PreviewFileResponse
from exavault.models.quota import Quota
from exavault.models.relationship_data import RelationshipData
from exavault.models.resend_invitations_request_body import ResendInvitationsRequestBody
from exavault.models.resource import Resource
from exavault.models.resource_attributes import ResourceAttributes
from exavault.models.resource_collection_response import ResourceCollectionResponse
from exavault.models.resource_copy_move import ResourceCopyMove
from exavault.models.resource_delete import ResourceDelete
from exavault.models.resource_multi_response import ResourceMultiResponse
from exavault.models.resource_relationships import ResourceRelationships
from exavault.models.resource_relationships_data import ResourceRelationshipsData
from exavault.models.resource_relationships_direct_file import ResourceRelationshipsDirectFile
from exavault.models.resource_relationships_direct_file_data import ResourceRelationshipsDirectFileData
from exavault.models.resource_relationships_notifications import ResourceRelationshipsNotifications
from exavault.models.resource_relationships_parent_resource import ResourceRelationshipsParentResource
from exavault.models.resource_relationships_parent_resource_data import ResourceRelationshipsParentResourceData
from exavault.models.resource_relationships_share import ResourceRelationshipsShare
from exavault.models.resource_relationships_share_data import ResourceRelationshipsShareData
from exavault.models.resource_response import ResourceResponse
from exavault.models.send_referral_email_request_body import SendReferralEmailRequestBody
from exavault.models.session_activity_entry import SessionActivityEntry
from exavault.models.session_activity_entry_attributes import SessionActivityEntryAttributes
from exavault.models.session_activity_response import SessionActivityResponse
from exavault.models.share import Share
from exavault.models.share_attributes import ShareAttributes
from exavault.models.share_collection_response import ShareCollectionResponse
from exavault.models.share_message import ShareMessage
from exavault.models.share_message_attributes import ShareMessageAttributes
from exavault.models.share_message_data import ShareMessageData
from exavault.models.share_recipient import ShareRecipient
from exavault.models.share_recipients_response import ShareRecipientsResponse
from exavault.models.share_relationships import ShareRelationships
from exavault.models.share_relationships_data import ShareRelationshipsData
from exavault.models.share_relationships_message import ShareRelationshipsMessage
from exavault.models.share_relationships_notification import ShareRelationshipsNotification
from exavault.models.share_relationships_owner import ShareRelationshipsOwner
from exavault.models.share_relationships_owner_data import ShareRelationshipsOwnerData
from exavault.models.share_relationships_resource import ShareRelationshipsResource
from exavault.models.share_resource_data import ShareResourceData
from exavault.models.share_response import ShareResponse
from exavault.models.shares_recipients import SharesRecipients
from exavault.models.update_account_request_body import UpdateAccountRequestBody
from exavault.models.update_email_list_request_body import UpdateEmailListRequestBody
from exavault.models.update_form_by_id_request_body import UpdateFormByIdRequestBody
from exavault.models.update_notification_by_id_request_body import UpdateNotificationByIdRequestBody
from exavault.models.update_resource_by_id_request_body import UpdateResourceByIdRequestBody
from exavault.models.update_share_request_body import UpdateShareRequestBody
from exavault.models.update_user_request_body import UpdateUserRequestBody
from exavault.models.user import User
from exavault.models.user_attributes import UserAttributes
from exavault.models.user_collection_response import UserCollectionResponse
from exavault.models.user_permissions import UserPermissions
from exavault.models.user_relationships import UserRelationships
from exavault.models.user_relationships_home_resource import UserRelationshipsHomeResource
from exavault.models.user_relationships_home_resource_data import UserRelationshipsHomeResourceData
from exavault.models.user_relationships_owner_account import UserRelationshipsOwnerAccount
from exavault.models.user_relationships_owner_account_data import UserRelationshipsOwnerAccountData
from exavault.models.user_response import UserResponse
from exavault.models.users_permissions import UsersPermissions
from exavault.models.webhooks_activity_entry import WebhooksActivityEntry
from exavault.models.webhooks_activity_entry_attributes import WebhooksActivityEntryAttributes
from exavault.models.webhooks_activity_response import WebhooksActivityResponse



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from exavault.api_client import ApiClient


class NotificationsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_notification(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Create a new notification  # noqa: E501

        Create a new notification for a [resource](#section/Identifying-Resources) in your account. Notifications can be sent via email or webhook;  - To enable email, pass an array of email addresses to the `recipients` parameter of this call.  - To enable webhooks, setup the webhook callback URL in your account settings via [PATCH /account](#operation/updateAccount).   **Notes:**   - Authenticated user should have [notifications permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions)   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_notification(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make API call.  (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param AddNotificationRequestBody body:
        :return: NotificationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_notification_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.add_notification_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def add_notification_with_http_info(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Create a new notification  # noqa: E501

        Create a new notification for a [resource](#section/Identifying-Resources) in your account. Notifications can be sent via email or webhook;  - To enable email, pass an array of email addresses to the `recipients` parameter of this call.  - To enable webhooks, setup the webhook callback URL in your account settings via [PATCH /account](#operation/updateAccount).   **Notes:**   - Authenticated user should have [notifications permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions)   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_notification_with_http_info(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make API call.  (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param AddNotificationRequestBody body:
        :return: NotificationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_notification" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `add_notification`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `add_notification`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/notifications', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NotificationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_notification_by_id(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Delete a notification  # noqa: E501

        Deletes a notification. Note that deleting a notification _only_ deletes the notification &ndash; it does not delete any underlying files or folders.  **Notes:**  - You need to have the [notifications permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions) to update a notification. - You can only delete notifications owned by your user account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_notification_by_id(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int id: ID of the notification. Use [GET /notifications](#operation/listNotifications) if you need to lookup an ID. (required)
        :return: EmptyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_notification_by_id_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_notification_by_id_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
            return data

    def delete_notification_by_id_with_http_info(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Delete a notification  # noqa: E501

        Deletes a notification. Note that deleting a notification _only_ deletes the notification &ndash; it does not delete any underlying files or folders.  **Notes:**  - You need to have the [notifications permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions) to update a notification. - You can only delete notifications owned by your user account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_notification_by_id_with_http_info(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int id: ID of the notification. Use [GET /notifications](#operation/listNotifications) if you need to lookup an ID. (required)
        :return: EmptyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_notification_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `delete_notification_by_id`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `delete_notification_by_id`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_notification_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/notifications/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmptyResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_notification_by_id(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Get notification details  # noqa: E501

        Get the details for a notification with a specific ID number. You'll be able to review its path, triggers and who's getting the notification.   **Notes**  - You need to have the [notifications permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions) to view the detail for a notification. - You can only retrieve notifications owned by your user account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_notification_by_id(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int id: ID of the notification. Use [GET /notifications](#operation/listNotifications) if you need to lookup an ID. (required)
        :param str include: Related record types to include in the response. You can include multiple types by separating them with commas. Valid options are **ownerUser**, **resource**, and **share**.
        :return: NotificationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_notification_by_id_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_notification_by_id_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
            return data

    def get_notification_by_id_with_http_info(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Get notification details  # noqa: E501

        Get the details for a notification with a specific ID number. You'll be able to review its path, triggers and who's getting the notification.   **Notes**  - You need to have the [notifications permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions) to view the detail for a notification. - You can only retrieve notifications owned by your user account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_notification_by_id_with_http_info(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int id: ID of the notification. Use [GET /notifications](#operation/listNotifications) if you need to lookup an ID. (required)
        :param str include: Related record types to include in the response. You can include multiple types by separating them with commas. Valid options are **ownerUser**, **resource**, and **share**.
        :return: NotificationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'id', 'include']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_notification_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `get_notification_by_id`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `get_notification_by_id`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_notification_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'include' in params:
            query_params.append(('include', params['include']))  # noqa: E501

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/notifications/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NotificationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_notifications(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get a list of notifications  # noqa: E501

        Get a list of all the [notifications](/docs/account/06-notifications) you have access to. You can use sorting and filtering to limit the returned list.  **Notes:**   - Authenticated user should have [notifications permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_notifications(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call.  (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param str type: Type of notification include in the list. Valid options are **file**, **folder**, **send_receipt**, **share_receipt**, **file_drop**  If this parameter is not used, only **file** and **folder** type notifications are included in the list.
        :param int offset: Starting notification record in the result set. Can be used for pagination.
        :param str sort: What order the list of matches should be in. Valid sort fields are **resourcename**, **date**, **action** and **type**. The sort order for each sort field is ascending unless it is prefixed with a minus (“-“), in which case it will be descending.  You can chose multiple options for the sort by separating them with commmas, such as \"type,-date\" to sort by type, then most recent.
        :param int limit: Number of notification records to return. Can be used for pagination.
        :param str include: Related records to include in the response. Valid options are **ownerUser**, **resource**, **share**
        :param str action: The kind of action which triggers the notification. Valid choices are **connect** (only for delivery receipts), **download**, **upload**, **delete**, or **all**   **Note** The **all** action matches notifications set to \"all\", not all notifications. For example, notifications set to trigger only on delete are not included if you filter for action=all
        :return: NotificationCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_notifications_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.list_notifications_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def list_notifications_with_http_info(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get a list of notifications  # noqa: E501

        Get a list of all the [notifications](/docs/account/06-notifications) you have access to. You can use sorting and filtering to limit the returned list.  **Notes:**   - Authenticated user should have [notifications permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_notifications_with_http_info(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call.  (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param str type: Type of notification include in the list. Valid options are **file**, **folder**, **send_receipt**, **share_receipt**, **file_drop**  If this parameter is not used, only **file** and **folder** type notifications are included in the list.
        :param int offset: Starting notification record in the result set. Can be used for pagination.
        :param str sort: What order the list of matches should be in. Valid sort fields are **resourcename**, **date**, **action** and **type**. The sort order for each sort field is ascending unless it is prefixed with a minus (“-“), in which case it will be descending.  You can chose multiple options for the sort by separating them with commmas, such as \"type,-date\" to sort by type, then most recent.
        :param int limit: Number of notification records to return. Can be used for pagination.
        :param str include: Related records to include in the response. Valid options are **ownerUser**, **resource**, **share**
        :param str action: The kind of action which triggers the notification. Valid choices are **connect** (only for delivery receipts), **download**, **upload**, **delete**, or **all**   **Note** The **all** action matches notifications set to \"all\", not all notifications. For example, notifications set to trigger only on delete are not included if you filter for action=all
        :return: NotificationCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'type', 'offset', 'sort', 'limit', 'include', 'action']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_notifications" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `list_notifications`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `list_notifications`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'type' in params:
            query_params.append(('type', params['type']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'sort' in params:
            query_params.append(('sort', params['sort']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'include' in params:
            query_params.append(('include', params['include']))  # noqa: E501
        if 'action' in params:
            query_params.append(('action', params['action']))  # noqa: E501

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/notifications', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NotificationCollectionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_notification_by_id(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Update a notification  # noqa: E501

        Update an existing notification. You can add additional emails or change the action or users that cause a notification to trigger.   When updating recipient emails, make sure your `recipients` parameter contains the full list of people who should be included on the notification. If you resend the list without an existing recipient, they will be deleted from the notification emails.   **Notes:**  - You need to have the [notifications permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions) to update a notification. - You can only change notifications owned by your user account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_notification_by_id(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int id: ID of the notification. Use [GET /notifications](#operation/listNotifications) if you need to lookup an ID. (required)
        :param UpdateNotificationByIdRequestBody body:
        :return: NotificationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_notification_by_id_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_notification_by_id_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
            return data

    def update_notification_by_id_with_http_info(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Update a notification  # noqa: E501

        Update an existing notification. You can add additional emails or change the action or users that cause a notification to trigger.   When updating recipient emails, make sure your `recipients` parameter contains the full list of people who should be included on the notification. If you resend the list without an existing recipient, they will be deleted from the notification emails.   **Notes:**  - You need to have the [notifications permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions) to update a notification. - You can only change notifications owned by your user account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_notification_by_id_with_http_info(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int id: ID of the notification. Use [GET /notifications](#operation/listNotifications) if you need to lookup an ID. (required)
        :param UpdateNotificationByIdRequestBody body:
        :return: NotificationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_notification_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `update_notification_by_id`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `update_notification_by_id`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_notification_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/notifications/{id}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NotificationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AccessMode(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'download': 'bool',
        'upload': 'bool',
        'modify': 'bool',
        'delete': 'bool'
    }

    attribute_map = {
        'download': 'download',
        'upload': 'upload',
        'modify': 'modify',
        'delete': 'delete'
    }

    def __init__(self, download=None, upload=None, modify=None, delete=None):  # noqa: E501
        """AccessMode - a model defined in Swagger"""  # noqa: E501
        self._download = None
        self._upload = None
        self._modify = None
        self._delete = None
        self.discriminator = None
        if download is not None:
            self.download = download
        if upload is not None:
            self.upload = upload
        if modify is not None:
            self.modify = modify
        if delete is not None:
            self.delete = delete

    @property
    def download(self):
        """Gets the download of this AccessMode.  # noqa: E501

        Whether share allows visitors to download  # noqa: E501

        :return: The download of this AccessMode.  # noqa: E501
        :rtype: bool
        """
        return self._download

    @download.setter
    def download(self, download):
        """Sets the download of this AccessMode.

        Whether share allows visitors to download  # noqa: E501

        :param download: The download of this AccessMode.  # noqa: E501
        :type: bool
        """

        self._download = download

    @property
    def upload(self):
        """Gets the upload of this AccessMode.  # noqa: E501

        Whether share allows visitors to upload  # noqa: E501

        :return: The upload of this AccessMode.  # noqa: E501
        :rtype: bool
        """
        return self._upload

    @upload.setter
    def upload(self, upload):
        """Sets the upload of this AccessMode.

        Whether share allows visitors to upload  # noqa: E501

        :param upload: The upload of this AccessMode.  # noqa: E501
        :type: bool
        """

        self._upload = upload

    @property
    def modify(self):
        """Gets the modify of this AccessMode.  # noqa: E501

        Whether share allows visitors to rename or move contents.  # noqa: E501

        :return: The modify of this AccessMode.  # noqa: E501
        :rtype: bool
        """
        return self._modify

    @modify.setter
    def modify(self, modify):
        """Sets the modify of this AccessMode.

        Whether share allows visitors to rename or move contents.  # noqa: E501

        :param modify: The modify of this AccessMode.  # noqa: E501
        :type: bool
        """

        self._modify = modify

    @property
    def delete(self):
        """Gets the delete of this AccessMode.  # noqa: E501

        Whether share allows visitors to delete contents  # noqa: E501

        :return: The delete of this AccessMode.  # noqa: E501
        :rtype: bool
        """
        return self._delete

    @delete.setter
    def delete(self, delete):
        """Sets the delete of this AccessMode.

        Whether share allows visitors to delete contents  # noqa: E501

        :param delete: The delete of this AccessMode.  # noqa: E501
        :type: bool
        """

        self._delete = delete

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AccessMode, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccessMode):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ShareAttributes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'has_password': 'bool',
        'public': 'bool',
        'access_mode': 'AccessMode',
        'access_description': 'str',
        'embed': 'bool',
        'hash': 'str',
        'owner_hash': 'str',
        'expiration': 'str',
        'expired': 'bool',
        'resent': 'datetime',
        'type': 'str',
        'require_email': 'bool',
        'file_drop_create_folders': 'bool',
        'paths': 'list[str]',
        'recipients': 'list[ShareRecipient]',
        'messages': 'list[ShareMessage]',
        'inherited': 'bool',
        'status': 'int',
        'has_notification': 'bool',
        'created': 'datetime',
        'modified': 'datetime',
        'tracking_status': 'str',
        'form_id': 'int'
    }

    attribute_map = {
        'name': 'name',
        'has_password': 'hasPassword',
        'public': 'public',
        'access_mode': 'accessMode',
        'access_description': 'accessDescription',
        'embed': 'embed',
        'hash': 'hash',
        'owner_hash': 'ownerHash',
        'expiration': 'expiration',
        'expired': 'expired',
        'resent': 'resent',
        'type': 'type',
        'require_email': 'requireEmail',
        'file_drop_create_folders': 'fileDropCreateFolders',
        'paths': 'paths',
        'recipients': 'recipients',
        'messages': 'messages',
        'inherited': 'inherited',
        'status': 'status',
        'has_notification': 'hasNotification',
        'created': 'created',
        'modified': 'modified',
        'tracking_status': 'trackingStatus',
        'form_id': 'formId'
    }

    def __init__(self, name=None, has_password=None, public=None, access_mode=None, access_description=None, embed=None, hash=None, owner_hash=None, expiration=None, expired=None, resent=None, type=None, require_email=None, file_drop_create_folders=None, paths=None, recipients=None, messages=None, inherited=None, status=None, has_notification=None, created=None, modified=None, tracking_status=None, form_id=None):  # noqa: E501
        """ShareAttributes - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._has_password = None
        self._public = None
        self._access_mode = None
        self._access_description = None
        self._embed = None
        self._hash = None
        self._owner_hash = None
        self._expiration = None
        self._expired = None
        self._resent = None
        self._type = None
        self._require_email = None
        self._file_drop_create_folders = None
        self._paths = None
        self._recipients = None
        self._messages = None
        self._inherited = None
        self._status = None
        self._has_notification = None
        self._created = None
        self._modified = None
        self._tracking_status = None
        self._form_id = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if has_password is not None:
            self.has_password = has_password
        if public is not None:
            self.public = public
        if access_mode is not None:
            self.access_mode = access_mode
        if access_description is not None:
            self.access_description = access_description
        if embed is not None:
            self.embed = embed
        if hash is not None:
            self.hash = hash
        if owner_hash is not None:
            self.owner_hash = owner_hash
        if expiration is not None:
            self.expiration = expiration
        if expired is not None:
            self.expired = expired
        if resent is not None:
            self.resent = resent
        if type is not None:
            self.type = type
        if require_email is not None:
            self.require_email = require_email
        if file_drop_create_folders is not None:
            self.file_drop_create_folders = file_drop_create_folders
        if paths is not None:
            self.paths = paths
        if recipients is not None:
            self.recipients = recipients
        if messages is not None:
            self.messages = messages
        if inherited is not None:
            self.inherited = inherited
        if status is not None:
            self.status = status
        if has_notification is not None:
            self.has_notification = has_notification
        if created is not None:
            self.created = created
        if modified is not None:
            self.modified = modified
        if tracking_status is not None:
            self.tracking_status = tracking_status
        if form_id is not None:
            self.form_id = form_id

    @property
    def name(self):
        """Gets the name of this ShareAttributes.  # noqa: E501

        Share name.  # noqa: E501

        :return: The name of this ShareAttributes.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ShareAttributes.

        Share name.  # noqa: E501

        :param name: The name of this ShareAttributes.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def has_password(self):
        """Gets the has_password of this ShareAttributes.  # noqa: E501

        True if the share has password.  # noqa: E501

        :return: The has_password of this ShareAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._has_password

    @has_password.setter
    def has_password(self, has_password):
        """Sets the has_password of this ShareAttributes.

        True if the share has password.  # noqa: E501

        :param has_password: The has_password of this ShareAttributes.  # noqa: E501
        :type: bool
        """

        self._has_password = has_password

    @property
    def public(self):
        """Gets the public of this ShareAttributes.  # noqa: E501

        True if the share has a public url.  # noqa: E501

        :return: The public of this ShareAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this ShareAttributes.

        True if the share has a public url.  # noqa: E501

        :param public: The public of this ShareAttributes.  # noqa: E501
        :type: bool
        """

        self._public = public

    @property
    def access_mode(self):
        """Gets the access_mode of this ShareAttributes.  # noqa: E501


        :return: The access_mode of this ShareAttributes.  # noqa: E501
        :rtype: AccessMode
        """
        return self._access_mode

    @access_mode.setter
    def access_mode(self, access_mode):
        """Sets the access_mode of this ShareAttributes.


        :param access_mode: The access_mode of this ShareAttributes.  # noqa: E501
        :type: AccessMode
        """

        self._access_mode = access_mode

    @property
    def access_description(self):
        """Gets the access_description of this ShareAttributes.  # noqa: E501

        Description of the share access rights.  # noqa: E501

        :return: The access_description of this ShareAttributes.  # noqa: E501
        :rtype: str
        """
        return self._access_description

    @access_description.setter
    def access_description(self, access_description):
        """Sets the access_description of this ShareAttributes.

        Description of the share access rights.  # noqa: E501

        :param access_description: The access_description of this ShareAttributes.  # noqa: E501
        :type: str
        """

        self._access_description = access_description

    @property
    def embed(self):
        """Gets the embed of this ShareAttributes.  # noqa: E501

        True if share can be embedded.  # noqa: E501

        :return: The embed of this ShareAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._embed

    @embed.setter
    def embed(self, embed):
        """Sets the embed of this ShareAttributes.

        True if share can be embedded.  # noqa: E501

        :param embed: The embed of this ShareAttributes.  # noqa: E501
        :type: bool
        """

        self._embed = embed

    @property
    def hash(self):
        """Gets the hash of this ShareAttributes.  # noqa: E501

        Share hash.  # noqa: E501

        :return: The hash of this ShareAttributes.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this ShareAttributes.

        Share hash.  # noqa: E501

        :param hash: The hash of this ShareAttributes.  # noqa: E501
        :type: str
        """

        self._hash = hash

    @property
    def owner_hash(self):
        """Gets the owner_hash of this ShareAttributes.  # noqa: E501

        Share owner's hash.  # noqa: E501

        :return: The owner_hash of this ShareAttributes.  # noqa: E501
        :rtype: str
        """
        return self._owner_hash

    @owner_hash.setter
    def owner_hash(self, owner_hash):
        """Sets the owner_hash of this ShareAttributes.

        Share owner's hash.  # noqa: E501

        :param owner_hash: The owner_hash of this ShareAttributes.  # noqa: E501
        :type: str
        """

        self._owner_hash = owner_hash

    @property
    def expiration(self):
        """Gets the expiration of this ShareAttributes.  # noqa: E501

        Expiration date of the share.  # noqa: E501

        :return: The expiration of this ShareAttributes.  # noqa: E501
        :rtype: str
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """Sets the expiration of this ShareAttributes.

        Expiration date of the share.  # noqa: E501

        :param expiration: The expiration of this ShareAttributes.  # noqa: E501
        :type: str
        """

        self._expiration = expiration

    @property
    def expired(self):
        """Gets the expired of this ShareAttributes.  # noqa: E501

        True if the share has expired.  # noqa: E501

        :return: The expired of this ShareAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._expired

    @expired.setter
    def expired(self, expired):
        """Sets the expired of this ShareAttributes.

        True if the share has expired.  # noqa: E501

        :param expired: The expired of this ShareAttributes.  # noqa: E501
        :type: bool
        """

        self._expired = expired

    @property
    def resent(self):
        """Gets the resent of this ShareAttributes.  # noqa: E501

        Invitations resent date. Can be `null` if resent never happened.  # noqa: E501

        :return: The resent of this ShareAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._resent

    @resent.setter
    def resent(self, resent):
        """Sets the resent of this ShareAttributes.

        Invitations resent date. Can be `null` if resent never happened.  # noqa: E501

        :param resent: The resent of this ShareAttributes.  # noqa: E501
        :type: datetime
        """

        self._resent = resent

    @property
    def type(self):
        """Gets the type of this ShareAttributes.  # noqa: E501

        Type of share.  # noqa: E501

        :return: The type of this ShareAttributes.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ShareAttributes.

        Type of share.  # noqa: E501

        :param type: The type of this ShareAttributes.  # noqa: E501
        :type: str
        """
        allowed_values = ["shared_folder", "send", "receive"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def require_email(self):
        """Gets the require_email of this ShareAttributes.  # noqa: E501

        True if share requires email to access.  # noqa: E501

        :return: The require_email of this ShareAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._require_email

    @require_email.setter
    def require_email(self, require_email):
        """Sets the require_email of this ShareAttributes.

        True if share requires email to access.  # noqa: E501

        :param require_email: The require_email of this ShareAttributes.  # noqa: E501
        :type: bool
        """

        self._require_email = require_email

    @property
    def file_drop_create_folders(self):
        """Gets the file_drop_create_folders of this ShareAttributes.  # noqa: E501

        Flag to show if separate folders should be created for each file upload to receive folder.  # noqa: E501

        :return: The file_drop_create_folders of this ShareAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._file_drop_create_folders

    @file_drop_create_folders.setter
    def file_drop_create_folders(self, file_drop_create_folders):
        """Sets the file_drop_create_folders of this ShareAttributes.

        Flag to show if separate folders should be created for each file upload to receive folder.  # noqa: E501

        :param file_drop_create_folders: The file_drop_create_folders of this ShareAttributes.  # noqa: E501
        :type: bool
        """

        self._file_drop_create_folders = file_drop_create_folders

    @property
    def paths(self):
        """Gets the paths of this ShareAttributes.  # noqa: E501

        Path to the shared resource in your account.  # noqa: E501

        :return: The paths of this ShareAttributes.  # noqa: E501
        :rtype: list[str]
        """
        return self._paths

    @paths.setter
    def paths(self, paths):
        """Sets the paths of this ShareAttributes.

        Path to the shared resource in your account.  # noqa: E501

        :param paths: The paths of this ShareAttributes.  # noqa: E501
        :type: list[str]
        """

        self._paths = paths

    @property
    def recipients(self):
        """Gets the recipients of this ShareAttributes.  # noqa: E501

        Array of recipients.  # noqa: E501

        :return: The recipients of this ShareAttributes.  # noqa: E501
        :rtype: list[ShareRecipient]
        """
        return self._recipients

    @recipients.setter
    def recipients(self, recipients):
        """Sets the recipients of this ShareAttributes.

        Array of recipients.  # noqa: E501

        :param recipients: The recipients of this ShareAttributes.  # noqa: E501
        :type: list[ShareRecipient]
        """

        self._recipients = recipients

    @property
    def messages(self):
        """Gets the messages of this ShareAttributes.  # noqa: E501

        Array of invitation messages.  # noqa: E501

        :return: The messages of this ShareAttributes.  # noqa: E501
        :rtype: list[ShareMessage]
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        """Sets the messages of this ShareAttributes.

        Array of invitation messages.  # noqa: E501

        :param messages: The messages of this ShareAttributes.  # noqa: E501
        :type: list[ShareMessage]
        """

        self._messages = messages

    @property
    def inherited(self):
        """Gets the inherited of this ShareAttributes.  # noqa: E501

        True if share inherited from parent folder.  # noqa: E501

        :return: The inherited of this ShareAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._inherited

    @inherited.setter
    def inherited(self, inherited):
        """Sets the inherited of this ShareAttributes.

        True if share inherited from parent folder.  # noqa: E501

        :param inherited: The inherited of this ShareAttributes.  # noqa: E501
        :type: bool
        """

        self._inherited = inherited

    @property
    def status(self):
        """Gets the status of this ShareAttributes.  # noqa: E501

        Share activity status. Can be active (1) or deactivated (0).  # noqa: E501

        :return: The status of this ShareAttributes.  # noqa: E501
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ShareAttributes.

        Share activity status. Can be active (1) or deactivated (0).  # noqa: E501

        :param status: The status of this ShareAttributes.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def has_notification(self):
        """Gets the has_notification of this ShareAttributes.  # noqa: E501

        True if share has notification.  # noqa: E501

        :return: The has_notification of this ShareAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._has_notification

    @has_notification.setter
    def has_notification(self, has_notification):
        """Sets the has_notification of this ShareAttributes.

        True if share has notification.  # noqa: E501

        :param has_notification: The has_notification of this ShareAttributes.  # noqa: E501
        :type: bool
        """

        self._has_notification = has_notification

    @property
    def created(self):
        """Gets the created of this ShareAttributes.  # noqa: E501

        Timestamp of share creation.  # noqa: E501

        :return: The created of this ShareAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ShareAttributes.

        Timestamp of share creation.  # noqa: E501

        :param created: The created of this ShareAttributes.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def modified(self):
        """Gets the modified of this ShareAttributes.  # noqa: E501

        Timestamp of share modification. Can be `null` if it wasn't modified.  # noqa: E501

        :return: The modified of this ShareAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this ShareAttributes.

        Timestamp of share modification. Can be `null` if it wasn't modified.  # noqa: E501

        :param modified: The modified of this ShareAttributes.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def tracking_status(self):
        """Gets the tracking_status of this ShareAttributes.  # noqa: E501

        Checks recipient received status and returns whether it's been received (`complete`,) partial received (`incomplete`,) or not received yet (`pending`.)  # noqa: E501

        :return: The tracking_status of this ShareAttributes.  # noqa: E501
        :rtype: str
        """
        return self._tracking_status

    @tracking_status.setter
    def tracking_status(self, tracking_status):
        """Sets the tracking_status of this ShareAttributes.

        Checks recipient received status and returns whether it's been received (`complete`,) partial received (`incomplete`,) or not received yet (`pending`.)  # noqa: E501

        :param tracking_status: The tracking_status of this ShareAttributes.  # noqa: E501
        :type: str
        """
        allowed_values = ["complete", "incomplete", "pending"]  # noqa: E501
        if tracking_status not in allowed_values:
            raise ValueError(
                "Invalid value for `tracking_status` ({0}), must be one of {1}"  # noqa: E501
                .format(tracking_status, allowed_values)
            )

        self._tracking_status = tracking_status

    @property
    def form_id(self):
        """Gets the form_id of this ShareAttributes.  # noqa: E501

        ID of the form.  # noqa: E501

        :return: The form_id of this ShareAttributes.  # noqa: E501
        :rtype: int
        """
        return self._form_id

    @form_id.setter
    def form_id(self, form_id):
        """Sets the form_id of this ShareAttributes.

        ID of the form.  # noqa: E501

        :param form_id: The form_id of this ShareAttributes.  # noqa: E501
        :type: int
        """

        self._form_id = form_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ShareAttributes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShareAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddNotificationRequestBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'resource': 'str',
        'action': 'str',
        'usernames': 'list[str]',
        'send_email': 'bool',
        'recipients': 'list[str]',
        'message': 'str'
    }

    attribute_map = {
        'type': 'type',
        'resource': 'resource',
        'action': 'action',
        'usernames': 'usernames',
        'send_email': 'sendEmail',
        'recipients': 'recipients',
        'message': 'message'
    }

    def __init__(self, type=None, resource=None, action=None, usernames=None, send_email=None, recipients=None, message=None):  # noqa: E501
        """AddNotificationRequestBody - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._resource = None
        self._action = None
        self._usernames = None
        self._send_email = None
        self._recipients = None
        self._message = None
        self.discriminator = None
        self.type = type
        self.resource = resource
        self.action = action
        self.usernames = usernames
        self.send_email = send_email
        if recipients is not None:
            self.recipients = recipients
        if message is not None:
            self.message = message

    @property
    def type(self):
        """Gets the type of this AddNotificationRequestBody.  # noqa: E501

        What kind of notification you're making. Valid choices are:  - **file** to monitor activity for a file resource - **folder** to monitor activity for a folder resource  # noqa: E501

        :return: The type of this AddNotificationRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AddNotificationRequestBody.

        What kind of notification you're making. Valid choices are:  - **file** to monitor activity for a file resource - **folder** to monitor activity for a folder resource  # noqa: E501

        :param type: The type of this AddNotificationRequestBody.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["file", "folder"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def resource(self):
        """Gets the resource of this AddNotificationRequestBody.  # noqa: E501

        Resources for this notification. See details on [how to specify resources](#section/Identifying-Resources) above.  # noqa: E501

        :return: The resource of this AddNotificationRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """Sets the resource of this AddNotificationRequestBody.

        Resources for this notification. See details on [how to specify resources](#section/Identifying-Resources) above.  # noqa: E501

        :param resource: The resource of this AddNotificationRequestBody.  # noqa: E501
        :type: str
        """
        if resource is None:
            raise ValueError("Invalid value for `resource`, must not be `None`")  # noqa: E501

        self._resource = resource

    @property
    def action(self):
        """Gets the action of this AddNotificationRequestBody.  # noqa: E501

        Type of action be notified about. Notifications will only be fired for the given type of action. Valid choices are **upload**, **download**, **delete** or **all** (upload/download/delete)  # noqa: E501

        :return: The action of this AddNotificationRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this AddNotificationRequestBody.

        Type of action be notified about. Notifications will only be fired for the given type of action. Valid choices are **upload**, **download**, **delete** or **all** (upload/download/delete)  # noqa: E501

        :param action: The action of this AddNotificationRequestBody.  # noqa: E501
        :type: str
        """
        if action is None:
            raise ValueError("Invalid value for `action`, must not be `None`")  # noqa: E501
        allowed_values = ["upload", "download", "delete", "all"]  # noqa: E501
        if action not in allowed_values:
            raise ValueError(
                "Invalid value for `action` ({0}), must be one of {1}"  # noqa: E501
                .format(action, allowed_values)
            )

        self._action = action

    @property
    def usernames(self):
        """Gets the usernames of this AddNotificationRequestBody.  # noqa: E501

        Determines which users' actions should trigger the notification.   Rather than listing  individual users, you can also use 3 special options:  - **notice\\_user\\_all** for activity by any user or share recipient - **notice\\_user\\_all\\_users** for activity only by user accounts - **notice\\_user\\_all\\_recipient** for activity only by share recipients  # noqa: E501

        :return: The usernames of this AddNotificationRequestBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._usernames

    @usernames.setter
    def usernames(self, usernames):
        """Sets the usernames of this AddNotificationRequestBody.

        Determines which users' actions should trigger the notification.   Rather than listing  individual users, you can also use 3 special options:  - **notice\\_user\\_all** for activity by any user or share recipient - **notice\\_user\\_all\\_users** for activity only by user accounts - **notice\\_user\\_all\\_recipient** for activity only by share recipients  # noqa: E501

        :param usernames: The usernames of this AddNotificationRequestBody.  # noqa: E501
        :type: list[str]
        """
        if usernames is None:
            raise ValueError("Invalid value for `usernames`, must not be `None`")  # noqa: E501

        self._usernames = usernames

    @property
    def send_email(self):
        """Gets the send_email of this AddNotificationRequestBody.  # noqa: E501

        Set to true if the user should be notified by email when the notification is triggered.  # noqa: E501

        :return: The send_email of this AddNotificationRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._send_email

    @send_email.setter
    def send_email(self, send_email):
        """Sets the send_email of this AddNotificationRequestBody.

        Set to true if the user should be notified by email when the notification is triggered.  # noqa: E501

        :param send_email: The send_email of this AddNotificationRequestBody.  # noqa: E501
        :type: bool
        """
        if send_email is None:
            raise ValueError("Invalid value for `send_email`, must not be `None`")  # noqa: E501

        self._send_email = send_email

    @property
    def recipients(self):
        """Gets the recipients of this AddNotificationRequestBody.  # noqa: E501

        Email addresses to send notification emails to. If not specified, sends to the current user's email address.  # noqa: E501

        :return: The recipients of this AddNotificationRequestBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._recipients

    @recipients.setter
    def recipients(self, recipients):
        """Sets the recipients of this AddNotificationRequestBody.

        Email addresses to send notification emails to. If not specified, sends to the current user's email address.  # noqa: E501

        :param recipients: The recipients of this AddNotificationRequestBody.  # noqa: E501
        :type: list[str]
        """

        self._recipients = recipients

    @property
    def message(self):
        """Gets the message of this AddNotificationRequestBody.  # noqa: E501

        Custom message to include in notification emails.  # noqa: E501

        :return: The message of this AddNotificationRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this AddNotificationRequestBody.

        Custom message to include in notification emails.  # noqa: E501

        :param message: The message of this AddNotificationRequestBody.  # noqa: E501
        :type: str
        """

        self._message = message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddNotificationRequestBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddNotificationRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UserAttributes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'int',
        'locked': 'bool',
        'expiration': 'str',
        'created': 'datetime',
        'modified': 'datetime',
        'access_timestamp': 'str',
        'account_name': 'str',
        'username': 'str',
        'nickname': 'str',
        'email': 'str',
        'home_path': 'str',
        'permissions': 'UserPermissions',
        'role': 'str',
        'time_zone': 'str',
        'onboarding': 'bool',
        'first_login': 'bool'
    }

    attribute_map = {
        'status': 'status',
        'locked': 'locked',
        'expiration': 'expiration',
        'created': 'created',
        'modified': 'modified',
        'access_timestamp': 'accessTimestamp',
        'account_name': 'accountName',
        'username': 'username',
        'nickname': 'nickname',
        'email': 'email',
        'home_path': 'homePath',
        'permissions': 'permissions',
        'role': 'role',
        'time_zone': 'timeZone',
        'onboarding': 'onboarding',
        'first_login': 'firstLogin'
    }

    def __init__(self, status=None, locked=None, expiration=None, created=None, modified=None, access_timestamp=None, account_name=None, username=None, nickname=None, email=None, home_path=None, permissions=None, role=None, time_zone=None, onboarding=None, first_login=None):  # noqa: E501
        """UserAttributes - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._locked = None
        self._expiration = None
        self._created = None
        self._modified = None
        self._access_timestamp = None
        self._account_name = None
        self._username = None
        self._nickname = None
        self._email = None
        self._home_path = None
        self._permissions = None
        self._role = None
        self._time_zone = None
        self._onboarding = None
        self._first_login = None
        self.discriminator = None
        self.status = status
        if locked is not None:
            self.locked = locked
        if expiration is not None:
            self.expiration = expiration
        self.created = created
        self.modified = modified
        if access_timestamp is not None:
            self.access_timestamp = access_timestamp
        self.account_name = account_name
        self.username = username
        self.nickname = nickname
        if email is not None:
            self.email = email
        if home_path is not None:
            self.home_path = home_path
        self.permissions = permissions
        self.role = role
        self.time_zone = time_zone
        self.onboarding = onboarding
        if first_login is not None:
            self.first_login = first_login

    @property
    def status(self):
        """Gets the status of this UserAttributes.  # noqa: E501

        Indicates user activity status. `0` means the user is locked and cannot log in. `1` means the user is active and can log in.  # noqa: E501

        :return: The status of this UserAttributes.  # noqa: E501
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UserAttributes.

        Indicates user activity status. `0` means the user is locked and cannot log in. `1` means the user is active and can log in.  # noqa: E501

        :param status: The status of this UserAttributes.  # noqa: E501
        :type: int
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = [0, 1]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def locked(self):
        """Gets the locked of this UserAttributes.  # noqa: E501

        `true` if the user is locked and cannot log in.  # noqa: E501

        :return: The locked of this UserAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this UserAttributes.

        `true` if the user is locked and cannot log in.  # noqa: E501

        :param locked: The locked of this UserAttributes.  # noqa: E501
        :type: bool
        """

        self._locked = locked

    @property
    def expiration(self):
        """Gets the expiration of this UserAttributes.  # noqa: E501

        Timestamp of user expiration.  # noqa: E501

        :return: The expiration of this UserAttributes.  # noqa: E501
        :rtype: str
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """Sets the expiration of this UserAttributes.

        Timestamp of user expiration.  # noqa: E501

        :param expiration: The expiration of this UserAttributes.  # noqa: E501
        :type: str
        """

        self._expiration = expiration

    @property
    def created(self):
        """Gets the created of this UserAttributes.  # noqa: E501

        Timestamp of user creation.  # noqa: E501

        :return: The created of this UserAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this UserAttributes.

        Timestamp of user creation.  # noqa: E501

        :param created: The created of this UserAttributes.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def modified(self):
        """Gets the modified of this UserAttributes.  # noqa: E501

        Timestamp of user modification.  # noqa: E501

        :return: The modified of this UserAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this UserAttributes.

        Timestamp of user modification.  # noqa: E501

        :param modified: The modified of this UserAttributes.  # noqa: E501
        :type: datetime
        """
        if modified is None:
            raise ValueError("Invalid value for `modified`, must not be `None`")  # noqa: E501

        self._modified = modified

    @property
    def access_timestamp(self):
        """Gets the access_timestamp of this UserAttributes.  # noqa: E501

        Timestamp of most recent successful user login.  # noqa: E501

        :return: The access_timestamp of this UserAttributes.  # noqa: E501
        :rtype: str
        """
        return self._access_timestamp

    @access_timestamp.setter
    def access_timestamp(self, access_timestamp):
        """Sets the access_timestamp of this UserAttributes.

        Timestamp of most recent successful user login.  # noqa: E501

        :param access_timestamp: The access_timestamp of this UserAttributes.  # noqa: E501
        :type: str
        """

        self._access_timestamp = access_timestamp

    @property
    def account_name(self):
        """Gets the account_name of this UserAttributes.  # noqa: E501

        Name of the account this user belongs to.  # noqa: E501

        :return: The account_name of this UserAttributes.  # noqa: E501
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """Sets the account_name of this UserAttributes.

        Name of the account this user belongs to.  # noqa: E501

        :param account_name: The account_name of this UserAttributes.  # noqa: E501
        :type: str
        """
        if account_name is None:
            raise ValueError("Invalid value for `account_name`, must not be `None`")  # noqa: E501

        self._account_name = account_name

    @property
    def username(self):
        """Gets the username of this UserAttributes.  # noqa: E501

        Username of the user.  # noqa: E501

        :return: The username of this UserAttributes.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this UserAttributes.

        Username of the user.  # noqa: E501

        :param username: The username of this UserAttributes.  # noqa: E501
        :type: str
        """
        if username is None:
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501

        self._username = username

    @property
    def nickname(self):
        """Gets the nickname of this UserAttributes.  # noqa: E501

        Nickname of the user.  # noqa: E501

        :return: The nickname of this UserAttributes.  # noqa: E501
        :rtype: str
        """
        return self._nickname

    @nickname.setter
    def nickname(self, nickname):
        """Sets the nickname of this UserAttributes.

        Nickname of the user.  # noqa: E501

        :param nickname: The nickname of this UserAttributes.  # noqa: E501
        :type: str
        """
        if nickname is None:
            raise ValueError("Invalid value for `nickname`, must not be `None`")  # noqa: E501

        self._nickname = nickname

    @property
    def email(self):
        """Gets the email of this UserAttributes.  # noqa: E501

        Email address of the user.  # noqa: E501

        :return: The email of this UserAttributes.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UserAttributes.

        Email address of the user.  # noqa: E501

        :param email: The email of this UserAttributes.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def home_path(self):
        """Gets the home_path of this UserAttributes.  # noqa: E501

        Path to the user's home folder.  # noqa: E501

        :return: The home_path of this UserAttributes.  # noqa: E501
        :rtype: str
        """
        return self._home_path

    @home_path.setter
    def home_path(self, home_path):
        """Sets the home_path of this UserAttributes.

        Path to the user's home folder.  # noqa: E501

        :param home_path: The home_path of this UserAttributes.  # noqa: E501
        :type: str
        """

        self._home_path = home_path

    @property
    def permissions(self):
        """Gets the permissions of this UserAttributes.  # noqa: E501


        :return: The permissions of this UserAttributes.  # noqa: E501
        :rtype: UserPermissions
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this UserAttributes.


        :param permissions: The permissions of this UserAttributes.  # noqa: E501
        :type: UserPermissions
        """
        if permissions is None:
            raise ValueError("Invalid value for `permissions`, must not be `None`")  # noqa: E501

        self._permissions = permissions

    @property
    def role(self):
        """Gets the role of this UserAttributes.  # noqa: E501

        User's access level  # noqa: E501

        :return: The role of this UserAttributes.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this UserAttributes.

        User's access level  # noqa: E501

        :param role: The role of this UserAttributes.  # noqa: E501
        :type: str
        """
        if role is None:
            raise ValueError("Invalid value for `role`, must not be `None`")  # noqa: E501
        allowed_values = ["user", "admin", "master"]  # noqa: E501
        if role not in allowed_values:
            raise ValueError(
                "Invalid value for `role` ({0}), must be one of {1}"  # noqa: E501
                .format(role, allowed_values)
            )

        self._role = role

    @property
    def time_zone(self):
        """Gets the time_zone of this UserAttributes.  # noqa: E501

        User's timezone. See <a href='https://php.net/manual/en/timezones.php' target='blank'>this page</a> for allowed values.  # noqa: E501

        :return: The time_zone of this UserAttributes.  # noqa: E501
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this UserAttributes.

        User's timezone. See <a href='https://php.net/manual/en/timezones.php' target='blank'>this page</a> for allowed values.  # noqa: E501

        :param time_zone: The time_zone of this UserAttributes.  # noqa: E501
        :type: str
        """
        if time_zone is None:
            raise ValueError("Invalid value for `time_zone`, must not be `None`")  # noqa: E501

        self._time_zone = time_zone

    @property
    def onboarding(self):
        """Gets the onboarding of this UserAttributes.  # noqa: E501

        Whether the onboarding help system is enabled for this user. `true` means that additional help popups are displayed in the web application for this user.  # noqa: E501

        :return: The onboarding of this UserAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._onboarding

    @onboarding.setter
    def onboarding(self, onboarding):
        """Sets the onboarding of this UserAttributes.

        Whether the onboarding help system is enabled for this user. `true` means that additional help popups are displayed in the web application for this user.  # noqa: E501

        :param onboarding: The onboarding of this UserAttributes.  # noqa: E501
        :type: bool
        """
        if onboarding is None:
            raise ValueError("Invalid value for `onboarding`, must not be `None`")  # noqa: E501

        self._onboarding = onboarding

    @property
    def first_login(self):
        """Gets the first_login of this UserAttributes.  # noqa: E501

        `true` if the user has logged into the system.  # noqa: E501

        :return: The first_login of this UserAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._first_login

    @first_login.setter
    def first_login(self, first_login):
        """Sets the first_login of this UserAttributes.

        `true` if the user has logged into the system.  # noqa: E501

        :param first_login: The first_login of this UserAttributes.  # noqa: E501
        :type: bool
        """

        self._first_login = first_login

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserAttributes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
